@@ -19,9 +19,9 @@ sub insert {
 
     if ( !defined $self->{insert_sth} ) {
         $self->{insert_sth} =
-          $self->{dbh}->prepare_cached( "INSERT INTO $self->{table_name} (\""
-              . join( '","', 'id', 'a_session', map { s/'/''/g; $_ } @$index )
-              . '") VALUES ('
+          $self->{dbh}->prepare_cached( "INSERT INTO $self->{table_name} ("
+              . join( ',', 'id', 'a_session', map { s/'/''/g; $_ } @$index )
+              . ') VALUES ('
               . join( ',', ('?') x ( 2 + @$index ) )
               . ')' );
     }
